@@ -106,7 +106,7 @@ def images_to_tfrecord(root_path, record_file, c2l_file, mul_thread=None):
 def tf_image_augmentation(image, size, target_size=(224, 224), adjust_gamma=None, random_brightness=None,
                           resize_method="bilinear", random_contrast=None, rotate=None, zoom_range=None,
                           random_crop=None, random_flip_left_right=None, random_flip_up_down=None,
-                          keep_aspect=True, noise=None):
+                          keep_aspect=True, noise=None, random_aspect=False):
     """
     Args:
         image: image tensor
@@ -116,13 +116,14 @@ def tf_image_augmentation(image, size, target_size=(224, 224), adjust_gamma=None
         random_brightness: float，随机亮度值调整，0，1，0为原图，1为白色，推荐值：0-0.15
         resize_method: 调整
         random_contrast:随机对比度，None或者tuple/list, (lower,higher),大于1增加对比度，推荐(0.8,1.5)
-        rotate: float, 随机进行旋转,单位为弧度，2*3.14表示一圈
+        rotate: float, 随机进行旋转,单位为弧度，2*3.14表示一圈,推荐：0.5
         zoom_range:float or [lower, upper], 随机进行缩放 ，float的缩放范围为[1-zoom_range, 1+zoom_range]
         random_crop: float or tuple. 随机裁剪比例，ie:(0.9,0.9)
         random_flip_left_right: True or None左右翻转
         random_flip_up_down:True or None 上下翻转
-        keep_aspect:是否保持长宽比
+        keep_aspect: bool, 是否保持长宽比,
         noise:None or float, 是否添加随机噪声，推荐：0.03
+        random_aspect: 是否随机确定保留长宽比
     Returns:
 
     """
@@ -162,9 +163,16 @@ def tf_image_augmentation(image, size, target_size=(224, 224), adjust_gamma=None
     image = tf.image.random_flip_left_right(image) if random_flip_left_right else image
     image = tf.image.random_flip_up_down(image) if random_flip_up_down else image
     if target_size:
-        image = tf.image.resize(image, target_size,
-                                method=resize_method) if not keep_aspect else tf.image.resize_with_pad(image,
-                                                                                                       *target_size)
+        if random_aspect:
+            aspect = random.choice([True, False])
+            image = tf.image.resize(image, target_size,
+                                    method=resize_method) if not aspect else tf.image.resize_with_pad(image,
+                                                                                                      *target_size)
+        else:
+            image = tf.image.resize(image, target_size,
+                                    method=resize_method) if not keep_aspect else tf.image.resize_with_pad(image,
+                                                                                                           *target_size)
+
     return tf.clip_by_value(image, 0, 1)
 
 
